[SCM] WebKit Debian packaging branch, debian/experimental, updated. upstream/1.3.3-9427-gc2be6fc

jianli at chromium.org jianli at chromium.org
Wed Dec 22 14:46:36 UTC 2010


The following commit has been merged in the debian/experimental branch:
commit 58f89ebd4d06d3affd8380841d49c7e9968ba193
Author: jianli at chromium.org <jianli at chromium.org@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Tue Oct 19 23:02:14 2010 +0000

    Rename createBlobURL to createObjectURL and revokeBlobURL to
    revokeObjectURL per the latest File API spec.
    https://bugs.webkit.org/show_bug.cgi?id=47934
    
    Reviewed by Darin Fisher.
    
    WebCore:
    
    * inspector/front-end/ResourcesPanel.js:
    (WebInspector.ResourcesPanel.prototype._contextMenu):
    * inspector/front-end/utilities.js:
    * page/DOMWindow.cpp:
    (WebCore::DOMWindow::createObjectURL):
    (WebCore::DOMWindow::revokeObjectURL):
    * page/DOMWindow.h:
    * page/DOMWindow.idl:
    * workers/WorkerContext.cpp:
    (WebCore::WorkerContext::createObjectURL):
    (WebCore::WorkerContext::revokeObjectURL):
    * workers/WorkerContext.h:
    * workers/WorkerContext.idl:
    
    LayoutTests:
    
    Update all the related test and result files to account for the
    renaming changes.
    
    * fast/dom/Window/script-tests/window-property-descriptors.js:
    * fast/dom/Window/window-properties-expected.txt:
    * fast/dom/Window/window-properties.html:
    * fast/dom/script-tests/prototype-inheritance.js:
    * fast/files/apply-blob-url-to-img.html:
    * fast/files/apply-blob-url-to-xhr.html:
    * fast/files/create-blob-url-crash-expected.txt:
    * fast/files/create-blob-url-crash.html:
    * fast/files/revoke-blob-url-expected.txt:
    * fast/files/revoke-blob-url.html:
    * fast/files/workers/resources/worker-apply-blob-url-to-xhr.js:
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@70102 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/LayoutTests/ChangeLog b/LayoutTests/ChangeLog
index 31d85cb..b85e8e6 100644
--- a/LayoutTests/ChangeLog
+++ b/LayoutTests/ChangeLog
@@ -1,3 +1,26 @@
+2010-10-19  Jian Li  <jianli at chromium.org>
+
+        Reviewed by Darin Fisher.
+
+        Rename createBlobURL to createObjectURL and revokeBlobURL to
+        revokeObjectURL per the latest File API spec.
+        https://bugs.webkit.org/show_bug.cgi?id=47934
+
+        Update all the related test and result files to account for the
+        renaming changes.
+
+        * fast/dom/Window/script-tests/window-property-descriptors.js:
+        * fast/dom/Window/window-properties-expected.txt:
+        * fast/dom/Window/window-properties.html:
+        * fast/dom/script-tests/prototype-inheritance.js:
+        * fast/files/apply-blob-url-to-img.html:
+        * fast/files/apply-blob-url-to-xhr.html:
+        * fast/files/create-blob-url-crash-expected.txt:
+        * fast/files/create-blob-url-crash.html:
+        * fast/files/revoke-blob-url-expected.txt:
+        * fast/files/revoke-blob-url.html:
+        * fast/files/workers/resources/worker-apply-blob-url-to-xhr.js:
+
 2010-10-19  Jeremy Orlow  <jorlow at chromium.org>
 
         Reviewed by Nate Chapin.
diff --git a/LayoutTests/fast/dom/Window/script-tests/window-property-descriptors.js b/LayoutTests/fast/dom/Window/script-tests/window-property-descriptors.js
index 42b09dc..141b608 100644
--- a/LayoutTests/fast/dom/Window/script-tests/window-property-descriptors.js
+++ b/LayoutTests/fast/dom/Window/script-tests/window-property-descriptors.js
@@ -58,7 +58,7 @@ protoPropertyNames.sort();
 
 for (var i = 0; i < protoPropertyNames.length; ++i) {
     // Ignore these properties because they do not exist in all implementations.
-    if (protoPropertyNames[i] == "createBlobURL" || protoPropertyNames[i] == "revokeBlobURL")
+    if (protoPropertyNames[i] == "createObjectURL" || protoPropertyNames[i] == "revokeObjectURL")
         continue;
     if (protoPropertyNames[i] == "constructor")
         continue;
diff --git a/LayoutTests/fast/dom/Window/window-properties-expected.txt b/LayoutTests/fast/dom/Window/window-properties-expected.txt
index 96d69d4..8d4a40d 100644
--- a/LayoutTests/fast/dom/Window/window-properties-expected.txt
+++ b/LayoutTests/fast/dom/Window/window-properties-expected.txt
@@ -2204,7 +2204,7 @@ window.constructor.prototype.clearInterval [function]
 window.constructor.prototype.clearTimeout [function]
 window.constructor.prototype.close [function]
 window.constructor.prototype.confirm [function]
-window.constructor.prototype.createBlobURL [function]
+window.constructor.prototype.createObjectURL [function]
 window.constructor.prototype.dispatchEvent [function]
 window.constructor.prototype.find [function]
 window.constructor.prototype.focus [function]
@@ -2222,7 +2222,7 @@ window.constructor.prototype.releaseEvents [function]
 window.constructor.prototype.removeEventListener [function]
 window.constructor.prototype.resizeBy [function]
 window.constructor.prototype.resizeTo [function]
-window.constructor.prototype.revokeBlobURL [function]
+window.constructor.prototype.revokeObjectURL [function]
 window.constructor.prototype.scroll [function]
 window.constructor.prototype.scrollBy [function]
 window.constructor.prototype.scrollTo [function]
diff --git a/LayoutTests/fast/dom/Window/window-properties.html b/LayoutTests/fast/dom/Window/window-properties.html
index 24ea0c8..d597482 100644
--- a/LayoutTests/fast/dom/Window/window-properties.html
+++ b/LayoutTests/fast/dom/Window/window-properties.html
@@ -80,8 +80,8 @@ var __skip__ = {
     "window.DeviceMotionEvent" : 1,
     "window.ondevicemotion" : 1,
     "window.webkitPerformance" : 1,
-    "window.createBlobURL" : 1,
-    "window.revokeBlobURL" : 1,
+    "window.createObjectURL" : 1,
+    "window.revokeObjectURL" : 1,
 
     // showModalDialog is not implemented on all platforms in DumpRenderTree.
     "window.showModalDialog" : 1,
diff --git a/LayoutTests/fast/dom/script-tests/prototype-inheritance.js b/LayoutTests/fast/dom/script-tests/prototype-inheritance.js
index 2a7c624..88f2793 100644
--- a/LayoutTests/fast/dom/script-tests/prototype-inheritance.js
+++ b/LayoutTests/fast/dom/script-tests/prototype-inheritance.js
@@ -21,7 +21,7 @@ var skippedProperties = [
     "FileError", "FileReader", "requestFileSystem",
     "indexedDB", "IDBKeyRange", "IDBCursor", "IDBDatabase", "IDBDatabaseError", "IDBDatabaseException", "IDBErrorEvent", "IDBEvent", "IDBFactory", "IDBIndex", "IDBObjectStore", "IDBRequest", "IDBSuccessEvent", "IDBTransaction",
     "showModalDialog",
-    "createBlobURL", "revokeBlobURL",
+    "createObjectURL", "revokeObjectURL",
     "DeviceOrientationEvent",
     "DeviceMotionEvent",
     "TEMPORARY", "PERSISTENT",
diff --git a/LayoutTests/fast/files/apply-blob-url-to-img.html b/LayoutTests/fast/files/apply-blob-url-to-img.html
index e1edaee..e3c0892 100644
--- a/LayoutTests/fast/files/apply-blob-url-to-img.html
+++ b/LayoutTests/fast/files/apply-blob-url-to-img.html
@@ -17,7 +17,7 @@ function onInputFileChange()
     var img = document.getElementById('imgToReplace');
     log("Old image: " + img.width + " x " + img.height);
     img.onload = onImgLoad;
-    img.src = window.createBlobURL(file);
+    img.src = window.createObjectURL(file);
 }
 
 function onImgLoad()
diff --git a/LayoutTests/fast/files/apply-blob-url-to-xhr.html b/LayoutTests/fast/files/apply-blob-url-to-xhr.html
index e163d51..6c94570 100644
--- a/LayoutTests/fast/files/apply-blob-url-to-xhr.html
+++ b/LayoutTests/fast/files/apply-blob-url-to-xhr.html
@@ -26,7 +26,7 @@ function sendXMLHttpRequest(method, url)
 function onInputFileChange()
 {
     var file = document.getElementById("file").files[0];
-    var fileURL = window.createBlobURL(file);
+    var fileURL = window.createObjectURL(file);
 
     log("Test that XMLHttpRequest GET succeeds.");
     sendXMLHttpRequest("GET", fileURL);
@@ -35,7 +35,7 @@ function onInputFileChange()
     sendXMLHttpRequest("POST", fileURL);
 
     log("Test that XMLHttpRequest GET fails after the blob URL is revoked.");
-    window.revokeBlobURL(fileURL);
+    window.revokeObjectURL(fileURL);
     sendXMLHttpRequest("GET", fileURL);
 
     log("DONE");
diff --git a/LayoutTests/fast/files/create-blob-url-crash-expected.txt b/LayoutTests/fast/files/create-blob-url-crash-expected.txt
index 2b5356a..36081fa 100644
--- a/LayoutTests/fast/files/create-blob-url-crash-expected.txt
+++ b/LayoutTests/fast/files/create-blob-url-crash-expected.txt
@@ -1,4 +1,4 @@
-Test that createBlobURL with no argument should not cause crash.
+Test that createObjectURL with no argument should not cause crash.
 PASS
 DONE
 
diff --git a/LayoutTests/fast/files/create-blob-url-crash.html b/LayoutTests/fast/files/create-blob-url-crash.html
index 7b66221..51aefad 100644
--- a/LayoutTests/fast/files/create-blob-url-crash.html
+++ b/LayoutTests/fast/files/create-blob-url-crash.html
@@ -9,8 +9,8 @@ function log(message)
 
 function test()
 {
-    log("Test that createBlobURL with no argument should not cause crash.");
-    var url = createBlobURL();
+    log("Test that createObjectURL with no argument should not cause crash.");
+    var url = createObjectURL();
     log(url == undefined ? "PASS" : "FAIL");
 
     log("DONE");
diff --git a/LayoutTests/fast/files/revoke-blob-url-expected.txt b/LayoutTests/fast/files/revoke-blob-url-expected.txt
index 5c26191..efad151 100644
--- a/LayoutTests/fast/files/revoke-blob-url-expected.txt
+++ b/LayoutTests/fast/files/revoke-blob-url-expected.txt
@@ -1,10 +1,10 @@
-Test calling revokeBlobURL with no argument.
+Test calling revokeObjectURL with no argument.
 PASS
-Test calling revokeBlobURL with empty URL.
+Test calling revokeObjectURL with empty URL.
 PASS
-Test calling revokeBlobURL with invalid URL.
+Test calling revokeObjectURL with invalid URL.
 PASS
-Test calling revokeBlobURL with non-existent URL.
+Test calling revokeObjectURL with non-existent URL.
 PASS
 DONE
 
diff --git a/LayoutTests/fast/files/revoke-blob-url.html b/LayoutTests/fast/files/revoke-blob-url.html
index 16acb5c..7716ad7 100644
--- a/LayoutTests/fast/files/revoke-blob-url.html
+++ b/LayoutTests/fast/files/revoke-blob-url.html
@@ -9,20 +9,20 @@ function log(message)
 
 function test()
 {
-    log("Test calling revokeBlobURL with no argument.");
-    var url = revokeBlobURL();
+    log("Test calling revokeObjectURL with no argument.");
+    var url = revokeObjectURL();
     log(url == undefined ? "PASS" : "FAIL");
 
-    log("Test calling revokeBlobURL with empty URL.");
-    revokeBlobURL("");
+    log("Test calling revokeObjectURL with empty URL.");
+    revokeObjectURL("");
     log("PASS");
 
-    log("Test calling revokeBlobURL with invalid URL.");
-    revokeBlobURL("[foo bar]");
+    log("Test calling revokeObjectURL with invalid URL.");
+    revokeObjectURL("[foo bar]");
     log("PASS");
 
-    log("Test calling revokeBlobURL with non-existent URL.");
-    revokeBlobURL("blob:non-existent");
+    log("Test calling revokeObjectURL with non-existent URL.");
+    revokeObjectURL("blob:non-existent");
     log("PASS");
 
     log("DONE");
diff --git a/LayoutTests/fast/files/workers/resources/worker-apply-blob-url-to-xhr.js b/LayoutTests/fast/files/workers/resources/worker-apply-blob-url-to-xhr.js
index 62904e5..cdcd0cf 100644
--- a/LayoutTests/fast/files/workers/resources/worker-apply-blob-url-to-xhr.js
+++ b/LayoutTests/fast/files/workers/resources/worker-apply-blob-url-to-xhr.js
@@ -19,7 +19,7 @@ function sendXMLHttpRequest(method, url)
 onmessage = function(event)
 {
     var file = event.data;
-    var fileURL = createBlobURL(file);
+    var fileURL = createObjectURL(file);
 
     log("Test that XMLHttpRequest GET succeeds.");
     sendXMLHttpRequest("GET", fileURL);
@@ -29,7 +29,7 @@ onmessage = function(event)
     sendXMLHttpRequest("POST", fileURL);
 
     log("Test that XMLHttpRequest GET fails after the blob URL is revoked.");
-    revokeBlobURL(fileURL);
+    revokeObjectURL(fileURL);
     sendXMLHttpRequest("GET", fileURL);
 
     log("DONE");
diff --git a/WebCore/ChangeLog b/WebCore/ChangeLog
index 38c48b7..76209a9 100644
--- a/WebCore/ChangeLog
+++ b/WebCore/ChangeLog
@@ -1,3 +1,25 @@
+2010-10-19  Jian Li  <jianli at chromium.org>
+
+        Reviewed by Darin Fisher.
+
+        Rename createBlobURL to createObjectURL and revokeBlobURL to
+        revokeObjectURL per the latest File API spec.
+        https://bugs.webkit.org/show_bug.cgi?id=47934
+
+        * inspector/front-end/ResourcesPanel.js:
+        (WebInspector.ResourcesPanel.prototype._contextMenu):
+        * inspector/front-end/utilities.js:
+        * page/DOMWindow.cpp:
+        (WebCore::DOMWindow::createObjectURL):
+        (WebCore::DOMWindow::revokeObjectURL):
+        * page/DOMWindow.h:
+        * page/DOMWindow.idl:
+        * workers/WorkerContext.cpp:
+        (WebCore::WorkerContext::createObjectURL):
+        (WebCore::WorkerContext::revokeObjectURL):
+        * workers/WorkerContext.h:
+        * workers/WorkerContext.idl:
+
 2010-10-19  Alexey Proskuryakov  <ap at apple.com>
 
         Reviewed by Anders Carlsson.
diff --git a/WebCore/inspector/front-end/utilities.js b/WebCore/inspector/front-end/utilities.js
index 7f0ee5e..3aff6bb 100644
--- a/WebCore/inspector/front-end/utilities.js
+++ b/WebCore/inspector/front-end/utilities.js
@@ -997,6 +997,6 @@ function offerFileForDownload(contents)
     var builder = new BlobBuilder();
     builder.append(contents);
     var blob = builder.getBlob("application/octet-stream");
-    var url = window.createBlobURL(blob);
+    var url = window.createObjectURL(blob);
     window.open(url);
 }
diff --git a/WebCore/page/DOMWindow.cpp b/WebCore/page/DOMWindow.cpp
index 9d6c610..d756cce 100644
--- a/WebCore/page/DOMWindow.cpp
+++ b/WebCore/page/DOMWindow.cpp
@@ -1576,12 +1576,12 @@ EventTargetData* DOMWindow::ensureEventTargetData()
 }
 
 #if ENABLE(BLOB)
-String DOMWindow::createBlobURL(Blob* blob)
+String DOMWindow::createObjectURL(Blob* blob)
 {
     return scriptExecutionContext()->createPublicBlobURL(blob).string();
 }
 
-void DOMWindow::revokeBlobURL(const String& blobURLString)
+void DOMWindow::revokeObjectURL(const String& blobURLString)
 {
     scriptExecutionContext()->revokePublicBlobURL(KURL(KURL(), blobURLString));
 }
diff --git a/WebCore/page/DOMWindow.h b/WebCore/page/DOMWindow.h
index e958b38..2156791 100644
--- a/WebCore/page/DOMWindow.h
+++ b/WebCore/page/DOMWindow.h
@@ -392,8 +392,8 @@ namespace WebCore {
         DOMApplicationCache* optionalApplicationCache() const { return m_applicationCache.get(); }
 #endif
 #if ENABLE(BLOB)
-        String createBlobURL(Blob*);
-        void revokeBlobURL(const String&);
+        String createObjectURL(Blob*);
+        void revokeObjectURL(const String&);
 #endif
 
         using RefCounted<DOMWindow>::ref;
diff --git a/WebCore/page/DOMWindow.idl b/WebCore/page/DOMWindow.idl
index 0e83556..0ae1069 100644
--- a/WebCore/page/DOMWindow.idl
+++ b/WebCore/page/DOMWindow.idl
@@ -763,8 +763,8 @@ module window {
         attribute [Conditional=BLOB] BlobBuilderConstructor BlobBuilder;
 
 #if defined(ENABLE_BLOB) && ENABLE_BLOB
-        [ConvertNullStringTo=Undefined] DOMString createBlobURL(in Blob blob);
-        void revokeBlobURL(in DOMString blobURL);
+        [ConvertNullStringTo=Undefined] DOMString createObjectURL(in Blob blob);
+        void revokeObjectURL(in DOMString blobURL);
 #endif
 
 #endif // defined(LANGUAGE_JAVASCRIPT)
diff --git a/WebCore/workers/WorkerContext.cpp b/WebCore/workers/WorkerContext.cpp
index 478b360..a535191 100644
--- a/WebCore/workers/WorkerContext.cpp
+++ b/WebCore/workers/WorkerContext.cpp
@@ -340,12 +340,12 @@ EventTargetData* WorkerContext::ensureEventTargetData()
 }
 
 #if ENABLE(BLOB)
-String WorkerContext::createBlobURL(Blob* blob)
+String WorkerContext::createObjectURL(Blob* blob)
 {
     return scriptExecutionContext()->createPublicBlobURL(blob).string();
 }
 
-void WorkerContext::revokeBlobURL(const String& blobURLString)
+void WorkerContext::revokeObjectURL(const String& blobURLString)
 {
     scriptExecutionContext()->revokePublicBlobURL(KURL(ParsedURLString, blobURLString));
 }
diff --git a/WebCore/workers/WorkerContext.h b/WebCore/workers/WorkerContext.h
index 08804d2..5d15d94 100644
--- a/WebCore/workers/WorkerContext.h
+++ b/WebCore/workers/WorkerContext.h
@@ -121,8 +121,8 @@ namespace WebCore {
         virtual bool isJSExecutionTerminated() const;
 
 #if ENABLE(BLOB)
-        String createBlobURL(Blob*);
-        void revokeBlobURL(const String&);
+        String createObjectURL(Blob*);
+        void revokeObjectURL(const String&);
 #endif
 
 #if ENABLE(FILE_SYSTEM)
diff --git a/WebCore/workers/WorkerContext.idl b/WebCore/workers/WorkerContext.idl
index 9db4da0..45ac5b1 100644
--- a/WebCore/workers/WorkerContext.idl
+++ b/WebCore/workers/WorkerContext.idl
@@ -101,8 +101,8 @@ module threads {
         attribute BlobBuilderConstructor BlobBuilder;
         attribute FileReaderConstructor FileReader;
         attribute FileReaderSyncConstructor FileReaderSync;
-        DOMString createBlobURL(in Blob blob);
-        void revokeBlobURL(in DOMString blobURL);
+        DOMString createObjectURL(in Blob blob);
+        void revokeObjectURL(in DOMString blobURL);
 #endif
 
 #if defined(ENABLE_FILE_SYSTEM) && ENABLE_FILE_SYSTEM

diff --git a/WebCore/inspector/front-end/ResourcesPanel.js b/WebCore/inspector/front-end/ResourcesPanel.js
index 4cebf06..ae67bef 100644
--- a/WebCore/inspector/front-end/ResourcesPanel.js
+++ b/WebCore/inspector/front-end/ResourcesPanel.js
@@ -1274,8 +1274,8 @@ WebInspector.ResourcesPanel.prototype = {
             resource = resourceTreeItem.treeElement.representedObject;
 
         var needSeparator = false;
-        // createBlobURL is enabled conditionally, do not expose resource export if it's not available.
-        if (typeof window.createBlobURL === "function" && Preferences.resourceExportEnabled) {
+        // createObjectURL is enabled conditionally, do not expose resource export if it's not available.
+        if (typeof window.createObjectURL === "function" && Preferences.resourceExportEnabled) {
             if (resource)
                 contextMenu.appendItem(WebInspector.UIString("Export to HAR"), this._exportResource.bind(this, resource));
             contextMenu.appendItem(WebInspector.UIString("Export all to HAR"), this._exportAll.bind(this));
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list